Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(772)

Unified Diff: third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js

Issue 2852173002: DevTools: Show screenshots on the main flamechart (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js
diff --git a/third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js b/third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js
index 3cc65acc1bbcb7cc1d11fa1ae1ab84f0061bf4d9..87e30466edbe6aff37f138dacf6f5ec12d99d69a 100644
--- a/third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js
+++ b/third_party/WebKit/Source/devtools/front_end/perf_ui/FlameChart.js
@@ -1153,8 +1153,11 @@ PerfUI.FlameChart = class extends PerfUI.ChartViewport {
if (!isLastGroup && groups[index + 1].style.nestingLevel > style.nestingLevel)
return true;
var nextGroupLevel = isLastGroup ? this._dataProvider.maxStackDepth() : groups[index + 1].startLevel;
- // For groups that only have one line and share header line, pretend these are not collapsible.
- return nextGroupLevel !== groups[index].startLevel + 1;
+ if (nextGroupLevel !== groups[index].startLevel + 1)
+ return true;
+ // For groups that only have one line and share header line, pretend these are not collapsible
+ // unless the itemsHeight does not match the headerHeight
+ return style.height !== style.itemsHeight;
}
/**

Powered by Google App Engine
This is Rietveld 408576698